@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from reportlab.pdfgen import canvas
-from reportlab.lib.units import mm
+from reportlab.lib.units import mm, cm
 from reportlab.lib.colors import black, white
 from reportlab.graphics.barcode.common import I2of5
 import reportlab.lib.pagesizes
@@ -30,7 +30,7 @@ class BoletoPDF:
 
     def drawReciboSacadoCanhoto(self, boletoDados, x, y ):
         self.pdfCanvas.saveState();
-        self.pdfCanvas.translate( x*mm, y*mm );
+        self.pdfCanvas.translate( x, y );
 
         linhaInicial = 12
 
@@ -126,12 +126,12 @@ class BoletoPDF:
 
         self.pdfCanvas.restoreState();
 
-        return ( self.widthCanhoto/mm, 
-            ((linhaInicial+2)*self.heightLine)/mm )
+        return ( self.widthCanhoto, 
+            ((linhaInicial+2)*self.heightLine) )
 
     def drawReciboSacado(self, boletoDados, x, y ):
         self.pdfCanvas.saveState();
-        self.pdfCanvas.translate( x*mm, y*mm );
+        self.pdfCanvas.translate( x, y );
 
         linhaInicial = 16
 
@@ -301,6 +301,7 @@ class BoletoPDF:
             valorDocumento 
         )
 
+        self.pdfCanvas.setFont('Courier', 9 )
         demonstrativo = boletoDados.demonstrativo[0:25]
         for i in range(len(demonstrativo)):
             self.pdfCanvas.drawString( 
@@ -309,34 +310,36 @@ class BoletoPDF:
                 demonstrativo[i] 
             )
 
+        self.pdfCanvas.setFont('Helvetica', 9 )
+
         self.pdfCanvas.restoreState();
 
-        return (self.width/mm, ((linhaInicial+2)*self.heightLine)/mm);
+        return (self.width, ((linhaInicial+2)*self.heightLine));
 
     def drawHorizontalCorteLine(self, x, y, width ):
         self.pdfCanvas.saveState();
-        self.pdfCanvas.translate( x*mm, y*mm );
+        self.pdfCanvas.translate( x, y );
 
         self.pdfCanvas.setLineWidth(1)
         self.pdfCanvas.setDash(1,2)
-        self.__horizontalLine(0, 0, width*mm)
+        self.__horizontalLine(0, 0, width)
 
         self.pdfCanvas.restoreState();
 
     def drawVerticalCorteLine(self, x, y, height ):
         self.pdfCanvas.saveState();
-        self.pdfCanvas.translate( x*mm, y*mm );
+        self.pdfCanvas.translate( x, y );
 
         self.pdfCanvas.setLineWidth(1)
         self.pdfCanvas.setDash(1,2)
-        self.__verticalLine(0, 0, height*mm)
+        self.__verticalLine(0, 0, height)
 
         self.pdfCanvas.restoreState();
 
     def drawReciboCaixa(self, boletoDados, x, y ):
         self.pdfCanvas.saveState();
 
-        self.pdfCanvas.translate( x*mm, y*mm );
+        self.pdfCanvas.translate( x, y );
 
         # De baixo para cima posicao 0,0 esta no canto inferior esquerdo
         self.pdfCanvas.setFont('Helvetica', self.fontSizeTitle )
@@ -670,37 +673,40 @@ class BoletoPDF:
 
         self.pdfCanvas.restoreState();
 
-        return (self.width, (y+self.heightLine)/mm )
+        return (self.width, (y+self.heightLine) )
 
     def drawBoletoCarneDuplo(self, boletoDados1, boletoDados2 ):
-        y = 5
+        y = 5*mm
         d = self.drawBoletoCarne(boletoDados1, y)
-        y += d[1] + 6
+        y += d[1] + 6*mm
         #self.drawHorizontalCorteLine(0, y, d[0])
-        y += 7
+        y += 7*mm
         if( boletoDados2):
             self.drawBoletoCarne(boletoDados2, y)
 
     def drawBoletoCarne(self, boletoDados, y ):
-        x = 15
+        x = 15*mm
         d = self.drawReciboSacadoCanhoto(boletoDados, x, y)
-        x += d[0] + 8
+        x += d[0] + 8*mm
         self.drawVerticalCorteLine(x, y, d[1])
-        x += 8
+        x += 8*mm
         d = self.drawReciboCaixa(boletoDados, x, y)
         x += d[0]
         return (x,d[1])
 
     def drawBoleto(self, boletoDados ):
-        x = 10
-        y = 40
-        self.drawHorizontalCorteLine(x, y, self.width/mm)
-        y += 5
+        x = 3.5*mm
+        y = 0
+        #y += 2*mm
+        #self.drawHorizontalCorteLine(x, y, self.width)
+        y += 6*mm
         d = self.drawReciboCaixa(boletoDados, x, y)
-        y += d[1] + 10
-        self.drawHorizontalCorteLine(x, y, self.width/mm)
-        y += 10
+        y += d[1] + (25*mm)
+        self.drawHorizontalCorteLine(x, y, self.width)
+        y += 15*mm
         d = self.drawReciboSacado(boletoDados, x, y)
+        y += d[1] + 10*mm
+        print y/cm
         return (self.width,y)
 
     def nextPage(self):
